<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>About</name>
    <message>
        <location filename="../components/About.qml" line="9"/>
        <source>About</source>
        <translation>Ohjelmasta</translation>
    </message>
    <message>
        <location filename="../components/About.qml" line="80"/>
        <source>&lt;p&gt;This service is paid for entirely by donations from users like you. &lt;a href=&quot;%1&quot;&gt;Please donate&lt;/a&gt;.&lt;/p&gt;</source>
        <extracomment>donation text of the about dialog</extracomment>
        <translation>&lt;p&gt;Tämä palvelu maksetaan kokonaan kaltaistesi käyttäjien lahjoituksilla. &lt;a href=&quot;%1&quot;&gt;Ole hyvä ja lahjoita&lt;/a&gt;.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../components/About.qml" line="103"/>
        <source>%1 version: 
%2</source>
        <extracomment>screenshot https://0xacab.org/leap/bitmask-vpn/-/blob/main/docs/screenshots/about.png %1 -&gt; application name %2 -&gt; version string</extracomment>
        <translation>Versio %1:ta: 
%2</translation>
    </message>
</context>
<context>
    <name>Footer</name>
    <message>
        <location filename="../components/Footer.qml" line="180"/>
        <source>Recommended</source>
        <translation>Suositeltu</translation>
    </message>
</context>
<context>
    <name>Help</name>
    <message>
        <location filename="../components/Help.qml" line="7"/>
        <source>Help</source>
        <translation>Ohje</translation>
    </message>
    <message>
        <location filename="../components/Help.qml" line="20"/>
        <source>Troubleshooting and support</source>
        <translation>Vianmääritys ja tuki</translation>
    </message>
    <message>
        <location filename="../components/Help.qml" line="31"/>
        <source>Report a bug</source>
        <translation>Ilmoita viasta</translation>
    </message>
    <message>
        <location filename="../components/Help.qml" line="42"/>
        <source>How to uninstall</source>
        <translation>Kuinka poistaa asennus</translation>
    </message>
</context>
<context>
    <name>InitErrors</name>
    <message>
        <location filename="../components/InitErrors.qml" line="31"/>
        <source>Could not find helpers. Please check your installation</source>
        <translation>Auttajia ei löytynyt. Tarkista asennuksesi</translation>
    </message>
    <message>
        <location filename="../components/InitErrors.qml" line="44"/>
        <source>Could not find polkit agent.</source>
        <translation>Polkit-agenttia ei löytynyt.</translation>
    </message>
</context>
<context>
    <name>Locations</name>
    <message>
        <location filename="../components/Locations.qml" line="21"/>
        <source>Select Location</source>
        <translation>Valitse sijainti</translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="27"/>
        <source>Automatically use best connection</source>
        <extracomment>this is in the radio button for the auto selection</extracomment>
        <translation>Käytä automaattisesti parasta yhteyttä</translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="29"/>
        <source>Manually select</source>
        <extracomment>Location Selection: label for radio buttons that selects manually</extracomment>
        <translation>Valitse manuaalisesti</translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="31"/>
        <source>Switching gateway…</source>
        <extracomment>A little display to signal that the clicked gateway is being switched to</extracomment>
        <translation>Vaihdetaan yhdyskäytävää.</translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="33"/>
        <source>Only locations with bridges</source>
        <extracomment>Subtitle to explain that only bridge locations are shown in the selector</extracomment>
        <translation>Vain sijainnit, joissa on siltoja</translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="65"/>
        <source>Recommended</source>
        <extracomment>Location Selection: label for radio button that selects automatically</extracomment>
        <translation>Suositeltu</translation>
    </message>
</context>
<context>
    <name>MainView</name>
    <message>
        <location filename="../components/MainView.qml" line="43"/>
        <location filename="../components/MainView.qml" line="66"/>
        <source>Donate</source>
        <translation>Lahjoita</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="59"/>
        <source>Preferences</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="73"/>
        <source>Help</source>
        <translation>Ohje</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="80"/>
        <source>About</source>
        <translation>Ohjelmasta</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="87"/>
        <source>Quit</source>
        <translation>Poistu</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="111"/>
        <source>Please donate!</source>
        <translation>Ole hyvä ja lahjoita!</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="125"/>
        <source>This service is paid for entirely by donations from users like you. The cost of running the VPN is approximately 5 USD per person every month, but every little bit counts. Do you want to donate now?</source>
        <translation>Tämä palvelu maksetaan kokonaan kaltaistesi käyttäjien lahjoituksilla. VPN:n käyttökustannukset ovat noin 5 USD henkilöä kohden kuukaudessa, mutta jokaisella pienellä on merkitystä. Haluatko lahjoittaa nyt?</translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="../components/Preferences.qml" line="11"/>
        <source>Preferences</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="55"/>
        <source>Turn off the VPN to make changes</source>
        <translation>Kytke VPN pois päältä tehdäksesi muutoksia</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="71"/>
        <source>Language</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="105"/>
        <source>Censorship circumvention</source>
        <translation>Sensuurin kiertäminen</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="113"/>
        <source>These techniques can bypass censorship, but are slower. Use them only when needed.</source>
        <translation>Nämä tekniikat voivat ohittaa sensuurin, mutta ovat hitaampia. Käytä niitä vain tarvittaessa.</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="127"/>
        <source>Use obfs4 bridges</source>
        <translation>Käytä obfs4-siltoja</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="153"/>
        <source>Traffic is obfuscated to bypass blocks</source>
        <translation>Liikenne on hämärtynyt ohittamaan lohkot</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="167"/>
        <source>Use Snowflake</source>
        <translation>Käytä Snowflakea</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="182"/>
        <source>Snowflake needs Tor installed in your system</source>
        <translation>Snowflake tarvitsee Tor-selaimen asennettuna järjestelmääsi</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="195"/>
        <source>Transport</source>
        <translation>Kuljetus</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="203"/>
        <source>UDP can make the VPN faster. It might be blocked on some networks.</source>
        <translation>UDP voi tehdä VPN:stä nopeamman. Se voi olla estetty joissakin verkoissa.</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="216"/>
        <source>Use UDP if available</source>
        <translation>Käytä UDP:tä, jos mahdollista</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="231"/>
        <source>KCP might work when UDP is blocked on some networks.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="244"/>
        <source>Use KCP if available</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Splash</name>
    <message>
        <location filename="../components/Splash.qml" line="101"/>
        <source>There is a newer version available. </source>
        <translation>Saatavilla on uudempi versio.</translation>
    </message>
    <message>
        <location filename="../components/Splash.qml" line="101"/>
        <source>Make sure to &lt;a href=&quot;https://0xacab.org/leap/bitmask-vpn/-/blob/main/docs/uninstall.md&quot;&gt;uninstall&lt;/a&gt; the previous one before running the new installer.</source>
        <translation>Varmista, että&lt;a href=&quot;https://0xacab.org/leap/bitmask-vpn/-/blob/main/docs/uninstall.md&quot;&gt;poistat&lt;/a&gt;edellisen ennen uuden asennusohjelman suorittamista.</translation>
    </message>
    <message>
        <location filename="../components/Splash.qml" line="105"/>
        <source>UPGRADE NOW</source>
        <translation>Päivitä nyt</translation>
    </message>
</context>
<context>
    <name>StatusBox</name>
    <message>
        <location filename="../components/StatusBox.qml" line="78"/>
        <source>This can take several minutes</source>
        <translation>Tämä saattaa kestää useita minuutteja</translation>
    </message>
</context>
<context>
    <name>Systray</name>
    <message>
        <location filename="../components/Systray.qml" line="16"/>
        <source>Checking status…</source>
        <translation>Tarkistetaan tilaa.</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="36"/>
        <source>Donate</source>
        <translation>Lahjoita</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="45"/>
        <source>Hide</source>
        <extracomment>Part of the systray menu; show or hide the main app window</extracomment>
        <translation>Piilota</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="45"/>
        <source>Show</source>
        <translation>Näytä</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="57"/>
        <source>Quit</source>
        <extracomment>Part of the systray menu; quits the application</extracomment>
        <translation>Poistu</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="74"/>
        <source>Connect to</source>
        <translation>Yhdistä tähän</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="76"/>
        <source>Connect</source>
        <translation>Yhdistä</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="79"/>
        <source>Disconnect</source>
        <translation>Katkaise yhteys</translation>
    </message>
</context>
<context>
    <name>VPNState</name>
    <message>
        <location filename="../components/VPNState.qml" line="26"/>
        <source>Setting up</source>
        <translation>Asetetaan</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="51"/>
        <location filename="../components/VPNState.qml" line="153"/>
        <source>Connecting</source>
        <translation>Yhdistetään</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="82"/>
        <source>Unsecured
Connection</source>
        <translation>Suojaamaton
yhteys</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="117"/>
        <source>Secured
Connection</source>
        <translation>Turvattu
yhteys</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="265"/>
        <source>%1 off</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation>%1 pois päältä</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="265"/>
        <source>off</source>
        <translation>ei käytössä</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="268"/>
        <source>%1 on</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation>%1 päällä</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="271"/>
        <source>Connecting to %1</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation>Yhdistetään %1:een</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="274"/>
        <source>Stopping %1</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation>Pysäytetään %1</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="277"/>
        <source>%1 blocking internet</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation>%1 estämässä internetin</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="284"/>
        <source>pluggable transport connection</source>
        <translation>kytkettävä kuljetusliitäntä</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="286"/>
        <source>connection done</source>
        <translation>yhteys tehty</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="288"/>
        <source>doing handshake</source>
        <translation>tekemässä kädenpuristusta</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="290"/>
        <source>handshake done</source>
        <translation>kädenpuristus tehty</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="292"/>
        <source>creating one-hop connection</source>
        <translation>luodaan yhden hypyn yhteys</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="294"/>
        <source>requesting status</source>
        <translation>pyydetään tilaa</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="296"/>
        <source>loading status</source>
        <translation>Ladataan tila</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="298"/>
        <source>loading keys</source>
        <translation>ladataan avaimet</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="300"/>
        <source>requesting descriptors</source>
        <translation>pyydetään kuvauksia</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="302"/>
        <source>loading descriptors</source>
        <translation>ladataan kuvauksia</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="304"/>
        <source>creating circuit</source>
        <translation>luodaan piiri</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="306"/>
        <source>done</source>
        <translation>valmis</translation>
    </message>
</context>
<context>
    <name>VPNSwitch</name>
    <message>
        <location filename="../qml/VPNSwitch.qml" line="10"/>
        <source/>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="140"/>
        <source>: a fast and secure VPN. Powered by Bitmask.</source>
        <translation>: nopea ja turvallinen VPN. Voimanlähteenä Bitmask.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="147"/>
        <source>Do not show the systray icon (useful together with Gnome Shell extension, or to control VPN by other means).</source>
        <translation>Älä näytä järjestelmäpalkkikuvaketta (hyödyllinen yhdessä Gnome Shell -laajennuksen kanssa tai VPN:n ohjaamiseen muilla tavoilla).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="154"/>
        <source>Enable Web API.</source>
        <translation>Ota Web API käyttöön.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="160"/>
        <source>Install helpers (Linux only, requires sudo).</source>
        <translation>Asenna apuohjelmat (vain Linux, vaatii ’sudo)’.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="166"/>
        <source>Use obfs4 to obfuscate the traffic, if available in the provider.</source>
        <translation>Käytä obfs4:ää liikenteen hämärtämiseen, jos se on saatavilla palveluntarjoajalta.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="172"/>
        <source>Enable autostart.</source>
        <translation>Ota automaattinen käynnistys käyttöön.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="177"/>
        <source>Web API port (default: 8080)</source>
        <translation>Web API -portti (oletus: 8080)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="180"/>
        <source>Start the VPN, either &apos;on&apos; or &apos;off&apos;.</source>
        <translation>Käynnistä VPN, joko &quot;päällä&quot; tai &quot;pois päältä&quot;.</translation>
    </message>
</context>
</TS>